@@ -18,18 +18,24 @@ test_that("manifest has correct data types", {
 
 test_that("recommended packages are snapshotted", {
   skip_on_cran()
+  skip_if_not_installed("MASS")
+
   withr::local_options(renv.verbose = TRUE)
-  app <- local_temp_app(list("index.Rmd" = c(
-    "```{r}",
-    "library(MASS)",
-    "```"
-  )))
+  app <- local_temp_app(list(
+    "index.Rmd" = c(
+      "```{r}",
+      "library(MASS)",
+      "```"
+    )
+  ))
   deps <- snapshotRenvDependencies(app)
   expect_true("MASS" %in% deps$Package)
 })
 
 test_that("extra packages are snapshotted", {
   skip_on_cran()
+  skip_if_not_installed("foreign")
+
   withr::local_options(renv.verbose = TRUE)
   app <- local_temp_app(list("index.Rmd" = ""))
   deps <- snapshotRenvDependencies(app, extraPackages = c("foreign"))
@@ -39,22 +45,29 @@ test_that("extra packages are snapshotted", {
 test_that("works with BioC packages", {
   skip_on_cran()
   skip_on_ci()
-  app <- local_temp_app(list("index.R" = c(
-    "library(Biobase)"
-  )))
+
+  app <- local_temp_app(list(
+    "index.R" = c(
+      "library(Biobase)"
+    )
+  ))
   biocRepos <- BiocManager::repositories()
   withr::local_options(repos = biocRepos)
   expect_no_condition(
-    { deps <- snapshotRenvDependencies(app) },
+    {
+      deps <- snapshotRenvDependencies(app)
+    },
     class = "rsconnect_biocRepos"
   )
   Biobase <- deps[deps$Package == "Biobase", ]
   expect_equal(Biobase$Source, "Bioconductor")
   expect_equal(Biobase$Repository, biocRepos[["BioCsoft"]])
 
-  withr::local_options(repos = c(
-    CRAN = "https://cran.rstudio.com"
-  ))
+  withr::local_options(
+    repos = c(
+      CRAN = "https://cran.rstudio.com"
+    )
+  )
   expect_condition(
     deps <- snapshotRenvDependencies(app),
     class = "rsconnect_biocRepos"
@@ -68,6 +81,8 @@ test_that("works with BioC packages", {
 # https://github.com/rstudio/rsconnect/issues/968
 test_that("large directories are analyzed", {
   skip_on_cran()
+  skip_if_not_installed("foreign")
+
   app_dir <- local_temp_app(list("foo.R" = "library(foreign)"))
   data_dir <- file.path(app_dir, "data")
   dir.create(data_dir)
@@ -83,6 +98,9 @@ test_that("large directories are analyzed", {
 # parseRenvDependencies ---------------------------------------------------
 
 test_that("gets DESCRIPTION from renv & system libraries", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_options(renv.verbose = FALSE)
 
   app_dir <- local_temp_app(list("foo.R" = "library(foreign); library(MASS)"))
@@ -98,6 +116,9 @@ test_that("gets DESCRIPTION from renv & system libraries", {
 
 
 test_that("errors if library and project are inconsistent", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
   withr::local_options(renv.verbose = FALSE)
 
   app_dir <- local_temp_app(list("foo.R" = "library(foreign); library(MASS)"))
@@ -168,7 +189,11 @@ test_that("has special handling for CRAN packages", {
 })
 
 test_that("packages installed from other repos get correctly named", {
-  pkg <- list(Package = "pkg", Source = "Repository", Repository = "https://test2.com")
+  pkg <- list(
+    Package = "pkg",
+    Source = "Repository",
+    Repository = "https://test2.com"
+  )
   packages <- as.matrix(data.frame(
     Package = "pkg",
     Version = "1.0.0",
