@@ -1,3 +1,5 @@
+skip_on_cran()
+
 makeManifest <- function(appDir, appPrimaryDoc = NULL, ...) {
   writeManifest(appDir, appPrimaryDoc = appPrimaryDoc, ..., quiet = TRUE)
   manifestFile <- file.path(appDir, "manifest.json")
@@ -8,7 +10,8 @@ makeManifest <- function(appDir, appPrimaryDoc = NULL, ...) {
 }
 
 test_that("renv.lock is included for renv projects", {
-  skip_on_cran()
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
 
   withr::local_options(renv.verbose = FALSE)
 
@@ -22,7 +25,8 @@ test_that("renv.lock is included for renv projects", {
 })
 
 test_that("renv.lock is not included for non-renv projects", {
-  skip_on_cran()
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
 
   withr::local_options(renv.verbose = FALSE)
 
@@ -33,13 +37,15 @@ test_that("renv.lock is not included for non-renv projects", {
 })
 
 test_that("Rmd with reticulate as a dependency includes python in the manifest", {
-  skip_on_cran()
   skip_if_not_installed("reticulate")
   python <- pythonPathOrSkip()
 
   appDir <- test_path("test-reticulate-rmds")
   manifest <- makeManifest(appDir, python = python)
-  requirements_file <- file.path(appDir, manifest$python$package_manager$package_file)
+  requirements_file <- file.path(
+    appDir,
+    manifest$python$package_manager$package_file
+  )
   expect_equal(requirements_file, "test-reticulate-rmds/requirements.txt")
   defer(unlink(requirements_file))
 
@@ -49,13 +55,15 @@ test_that("Rmd with reticulate as a dependency includes python in the manifest",
 })
 
 test_that("Rmd with reticulate as an inferred dependency includes reticulate and python in the manifest", {
-  skip_on_cran()
   skip_if_not_installed("reticulate")
   python <- pythonPathOrSkip()
 
   appDir <- test_path("test-reticulate-rmds")
   manifest <- makeManifest(appDir, "implicit.Rmd", python = python)
-  requirements_file <- file.path(appDir, manifest$python$package_manager$package_file)
+  requirements_file <- file.path(
+    appDir,
+    manifest$python$package_manager$package_file
+  )
   expect_equal(requirements_file, "test-reticulate-rmds/requirements.txt")
   defer(unlink(requirements_file))
 
@@ -65,8 +73,6 @@ test_that("Rmd with reticulate as an inferred dependency includes reticulate and
 })
 
 test_that("Rmd without a python block doesn't include reticulate or python in the manifest", {
-  skip_on_cran()
-
   manifest <- makeManifest(test_path("test-rmds"), "simple.Rmd", python = NULL)
   expect_equal(manifest$metadata$appmode, "rmd-static")
   expect_equal(manifest$metadata$primary_rmd, "simple.Rmd")
@@ -74,7 +80,6 @@ test_that("Rmd without a python block doesn't include reticulate or python in th
 })
 
 test_that("Rmd without a python block doesn't include reticulate or python in the manifest even if python specified", {
-  skip_on_cran()
   skip_if_not_installed("reticulate")
   python <- pythonPathOrSkip()
 
@@ -92,10 +97,9 @@ test_that("Rmd without a python block doesn't include reticulate or python in th
 # Quarto Tests
 
 test_that("Quarto website includes quarto in the manifest", {
-  skip_on_cran()
   skip_if_no_quarto()
 
-  appDir <- test_path("quarto-website-r")
+  appDir <- local_temp_app(quarto_website_r_files)
   manifest <- makeManifest(appDir, quarto = TRUE)
 
   expect_equal(manifest$metadata$appmode, "quarto-static")
@@ -104,7 +108,6 @@ test_that("Quarto website includes quarto in the manifest", {
 })
 
 test_that("Quarto document includes quarto in the manifest", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   appDir <- test_path("quarto-doc-none")
@@ -117,7 +120,6 @@ test_that("Quarto document includes quarto in the manifest", {
 })
 
 test_that("Specifying quarto arg includes quarto in the manifest, even with no appPrimaryDoc specified (.qmd)", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   appDir <- test_path("quarto-doc-none")
@@ -130,7 +132,6 @@ test_that("Specifying quarto arg includes quarto in the manifest, even with no a
 })
 
 test_that("Specifying quarto arg includes quarto in the manifest, even with no appPrimaryDoc specified (.Rmd)", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   appDir <- test_path("shiny-rmds")
@@ -143,7 +144,6 @@ test_that("Specifying quarto arg includes quarto in the manifest, even with no a
 })
 
 test_that("specifying quarto arg with non-quarto app does not include quarto in the manifest", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   appDir <- test_path("shinyapp-singleR")
@@ -154,7 +154,6 @@ test_that("specifying quarto arg with non-quarto app does not include quarto in
 })
 
 test_that("Quarto shiny project includes quarto in the manifest", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   appDir <- test_path("quarto-proj-r-shiny")
@@ -166,12 +165,11 @@ test_that("Quarto shiny project includes quarto in the manifest", {
 })
 
 test_that("Quarto R + Python website includes quarto and python in the manifest", {
-  skip_on_cran()
   skip_if_not_installed("reticulate")
   skip_if_no_quarto()
   python <- pythonPathOrSkip()
 
-  appDir <- test_path("quarto-website-r-py")
+  appDir <- local_temp_app(quarto_website_r_py_files)
   manifest <- makeManifest(appDir, python = python, quarto = TRUE)
 
   expect_equal(manifest$metadata$appmode, "quarto-static")
@@ -183,13 +181,12 @@ test_that("Quarto R + Python website includes quarto and python in the manifest"
 })
 
 test_that("Quarto Python-only website gets correct manifest data", {
-  skip_on_cran()
   skip_if_not_installed("reticulate")
   skip_if_no_quarto()
 
   python <- pythonPathOrSkip()
 
-  appDir <- test_path("quarto-website-py")
+  appDir <- local_temp_app(quarto_website_py_files)
   manifest <- makeManifest(appDir, python = python, quarto = TRUE)
 
   expect_equal(manifest$metadata$appmode, "quarto-static")
@@ -202,15 +199,13 @@ test_that("Quarto Python-only website gets correct manifest data", {
 })
 
 test_that("Deploying a Quarto project without Quarto is an error", {
-  skip_on_cran()
   local_mocked_bindings(quarto_path = function() NULL)
 
-  appDir <- test_path("quarto-website-r")
+  appDir <- local_temp_app(quarto_website_r_files)
   expect_snapshot(makeManifest(appDir), error = TRUE)
 })
 
 test_that("Deploying R Markdown content with Quarto gives a Quarto app mode", {
-  skip_on_cran()
   skip_if_no_quarto()
 
   manifest <- makeManifest(test_path("test-rmds"), "simple.Rmd", quarto = TRUE)
@@ -221,16 +216,12 @@ test_that("Deploying R Markdown content with Quarto gives a Quarto app mode", {
 })
 
 test_that("Deploying static content with _quarto.yaml succeeds without quartoInfo", {
-  skip_on_cran()
-
   manifest <- makeManifest(test_path("static-with-quarto-yaml"))
 
   expect_equal(manifest$metadata$appmode, "static")
 })
 
 test_that("environment.image is not set when image is not provided", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
 
   appDir <- test_path("shinyapp-simple")
@@ -240,8 +231,6 @@ test_that("environment.image is not set when image is not provided", {
 })
 
 test_that("TensorFlow models are identified", {
-  skip_on_cran()
-
   app_dir <- local_temp_app(list(
     "1/saved_model.pb" = "fake-saved-model"
   ))
@@ -252,8 +241,6 @@ test_that("TensorFlow models are identified", {
 })
 
 test_that("environment.image is set when image is provided", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
 
   appDir <- test_path("shinyapp-simple")
@@ -263,8 +250,6 @@ test_that("environment.image is set when image is provided", {
 })
 
 test_that("environment.image is set and uses a provided image even when RSCONNECT_IMAGE is set", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
   withr::local_envvar(RSCONNECT_IMAGE = "rstudio/content-base:older")
 
@@ -275,8 +260,6 @@ test_that("environment.image is set and uses a provided image even when RSCONNEC
 })
 
 test_that("environment.image is not set when RSCONNECT_IMAGE is empty", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
   withr::local_envvar(RSCONNECT_IMAGE = "")
 
@@ -287,8 +270,6 @@ test_that("environment.image is not set when RSCONNECT_IMAGE is empty", {
 })
 
 test_that("environment.image is set when RSCONNECT_IMAGE is nonempty", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
   withr::local_envvar(RSCONNECT_IMAGE = "rstudio/content-base:latest")
 
@@ -299,14 +280,17 @@ test_that("environment.image is set when RSCONNECT_IMAGE is nonempty", {
 })
 
 test_that("Sets environment.environment_management in the manifest if envManagement is defined", {
-  skip_on_cran()
-
   withr::local_options(renv.verbose = TRUE)
 
   appDir <- test_path("shinyapp-simple")
 
   # test shorthand arg
-  manifest <- makeManifest(appDir, envManagement = FALSE, envManagementR = TRUE, envManagementPy = TRUE)
+  manifest <- makeManifest(
+    appDir,
+    envManagement = FALSE,
+    envManagementR = TRUE,
+    envManagementPy = TRUE
+  )
   expect_equal(manifest$environment$environment_management$r, FALSE)
   expect_equal(manifest$environment$environment_management$python, FALSE)
 
@@ -323,11 +307,205 @@ test_that("Sets environment.environment_management in the manifest if envManagem
   expect_null(manifest$environment$environment_management)
 })
 
+test_that("environment.r.requires - DESCRIPTION file - existing Depends R is added", {
+  withr::local_options(renv.verbose = TRUE)
+
+  appDir <- test_path("packages/utf8package")
+  manifest <- makeManifest(appDir, appPrimaryDoc = "R/hello.R")
+  expect_equal(manifest$environment$r$requires, ">= 3.5.0")
+})
+
+test_that("environment.r.requires - renv.lock - Existing R version is added", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
+  withr::local_options(renv.verbose = FALSE)
+
+  appDir <- local_temp_app(list(app.R = "library(foreign); library(MASS)"))
+  renv::snapshot(appDir, prompt = FALSE)
+
+  manifest <- makeManifest(appDir)
+
+  maj <- R.Version()$major
+  min1 <- strsplit(R.Version()$minor, "\\.")[[1]][1]
+  expected <- sprintf("~=%s.%s.0", maj, min1)
+  expect_equal(
+    manifest$environment$r$requires,
+    expected
+  )
+})
+
+test_that("versionFromLockfile formats various R versions with patch .0", {
+  versions <- c("3", "3.8", "3.8.11", "3.25", "4.0.2", "10.5.3")
+  expected <- c(
+    "~=3.0",
+    "~=3.8.0",
+    "~=3.8.0",
+    "~=3.25.0",
+    "~=4.0.0",
+    "~=10.5.0"
+  )
+
+  for (i in seq_along(versions)) {
+    # Create a temporary directory with a renv.lock file
+    # containing the specified R version
+    appDir <- local_temp_app(list(
+      renv.lock = jsonlite::toJSON(
+        list(R = list(Version = versions[i])),
+        auto_unbox = TRUE
+      )
+    ))
+
+    res <- versionFromLockfile(appDir)
+    expect_equal(
+      res,
+      expected[i],
+      info = paste(
+        "Input:",
+        versions[i],
+        "→ got",
+        res,
+        "but expected",
+        expected[i]
+      )
+    )
+  }
+})
+
+test_that("environment.r.requires - DESCRIPTION file takes precedence over renv.lock", {
+  skip_if_not_installed("foreign")
+  skip_if_not_installed("MASS")
+
+  withr::local_options(renv.verbose = FALSE)
+
+  descFile <- "
+Package: oneshinyapp
+Title: Target for tests
+Version: 0.1.0
+Description: a test package
+Depends: R (>= 1.42.0)
+"
+  appDir <- local_temp_app(list(
+    app.R = "library(foreign); library(MASS)",
+    DESCRIPTION = descFile
+  ))
+  renv::snapshot(appDir, prompt = FALSE)
+
+  manifest <- makeManifest(appDir)
+  # Not sure if this is a valid or common scenario
+  # but here we are testing that DESCRIPTION file "Depends" takes precedence
+  expect_equal(manifest$environment$r$requires, ">= 1.42.0")
+})
+
+test_that("environment.r.requires - No DESCRIPTION and No renv.lock", {
+  withr::local_options(renv.verbose = TRUE)
+
+  appDir <- test_path("packages/windows1251package")
+  manifest <- makeManifest(appDir, appPrimaryDoc = "R/hello.R")
+  expect_null(manifest$environment)
+})
+
+test_that("environment.python.requires - .python-version file", {
+  skip_if_not_installed("reticulate")
+  skip_if_no_quarto()
+
+  withr::local_options(renv.verbose = TRUE)
+
+  python <- pythonPathOrSkip()
+
+  appDir <- local_temp_app(quarto_website_py_python_version_files)
+  manifest <- makeManifest(appDir, python = python, quarto = TRUE)
+  expect_equal(manifest$environment$python$requires, "~=3.8.0")
+})
+
+test_that("environment.python.requires - pyproject.toml", {
+  skip_if_not_installed("reticulate")
+  skip_if_no_quarto()
+
+  withr::local_options(renv.verbose = TRUE)
+
+  python <- pythonPathOrSkip()
+
+  appDir <- local_temp_app(quarto_website_r_py_files)
+  manifest <- makeManifest(appDir, python = python, quarto = TRUE)
+  expect_equal(manifest$environment$python$requires, ">=3.11")
+})
+
+test_that("environment.python.requires - setup.cfg", {
+  skip_if_not_installed("reticulate")
+  skip_if_no_quarto()
+
+  withr::local_options(renv.verbose = TRUE)
+
+  python <- pythonPathOrSkip()
+
+  appDir <- local_temp_app(quarto_website_py_setup_cfg_files)
+  manifest <- makeManifest(appDir, python = python, quarto = TRUE)
+  expect_equal(manifest$environment$python$requires, ">=3.9")
+})
+
+test_that(".python-version contents formats various Python versions with patch .0", {
+  python <- pythonPathOrSkip()
+  versions <- c(
+    "3",
+    "3.8",
+    "3.8.11",
+    "3.25",
+    "4.0.2",
+    "10.5.3",
+    # Existent specifier tokena are respected
+    ">=3.11",
+    "==3.99.0"
+  )
+  expected <- c(
+    "~=3.0",
+    "~=3.8.0",
+    "~=3.8.0",
+    "~=3.25.0",
+    "~=4.0.0",
+    "~=10.5.0",
+    ">=3.11",
+    "==3.99.0"
+  )
+
+  indexQmd <- "
+---
+title: \"quarto-website-py\"
+jupyter: python3
+---
+This is a Quarto website.
+```{python}
+1 + 1
+```
+"
+
+  for (i in seq_along(versions)) {
+    # Create a temporary directory with a .python-version file
+    # containing the specified Python version
+    appDir <- local_temp_app(list(
+      index.qmd = indexQmd,
+      `.python-version` = versions[i]
+    ))
+
+    manifest <- makeManifest(appDir, python = python, quarto = TRUE)
+    expect_equal(
+      manifest$environment$python$requires,
+      expected[i],
+      info = paste(
+        "Input:",
+        versions[i],
+        "→ got",
+        res,
+        "but expected",
+        expected[i]
+      )
+    )
+  }
+})
+
 # appMode Inference tests
 
 test_that("content type (appMode) is inferred and can be overridden", {
-  skip_on_cran()
-
   appDir <- local_temp_app(list(
     "app.R" = "",
     "index.html" = "",
